pub enum LockboxOpen<'a> {
ContentKey(SecureVec),
Password(&'a SecureString),
ContactKeyPair(ContactKeyPair),
}Expand description
Key material used to open an existing lockbox file.
Password and ContactKeyPair unwrap a stored content key from the
lockbox key directory. ContentKey is for callers that already hold the
content key and therefore do not need a key slot.
Variants
ContentKey(SecureVec)
Open directly with a caller-provided content key.
This must be the same high-entropy secret used with
LockboxProtection::ContentKey.
Password(&'a SecureString)
Open with a password key slot.
ContactKeyPair(ContactKeyPair)
Open with a contact keypair.
The keypair contains the private decapsulation material needed to unwrap a content key stored for its public key.