probe_lockbox_format_version

Function probe_lockbox_format_version 

pub fn probe_lockbox_format_version(bytes: &[u8]) -> Result<u16, Error>
Reads the stable native archive format discriminator from a complete, authenticated public header without attempting to parse that format.