pub struct CacheStats {
pub limit_bytes: u64,
pub used_bytes: u64,
pub entries: usize,
pub hits: u64,
pub misses: u64,
}Expand description
Snapshot of decoded-page cache usage.
Fields
limit_bytes: u64Current cache limit in bytes.
used_bytes: u64Approximate bytes currently held by decoded pages.
entries: usizeNumber of decoded page entries.
hits: u64Cache hit count since the current cache was created.
misses: u64Cache miss count since the current cache was created.