pub struct LockboxFileInspection {
pub lockbox_id: LockboxId,
pub header_readable: bool,
pub key_directory_generation: u64,
pub key_directory_copy_count: usize,
pub key_slots: Vec<LockboxKeySlot>,
pub owner_signed: bool,
}Expand description
Public metadata read from a lockbox file without decrypting its contents.
Fields
lockbox_id: LockboxIdStable id embedded in this lockbox.
header_readable: boolWhether the primary public header was readable and authenticated.
key_directory_generation: u64Best key-directory generation found in the lockbox file.
key_directory_copy_count: usizeNumber of readable key-directory copies found for this lockbox.
key_slots: Vec<LockboxKeySlot>Public key-slot metadata for access methods stored in the lockbox.
owner_signed: boolWhether the public header points at signed owner commit metadata.