pub struct OpenFileOptions {
pub create: bool,
pub truncate: bool,
pub permissions: Option<u32>,
}Expand description
Options used when opening a writable file handle inside a lockbox.
Fields
create: boolCreate the file if it does not already exist.
truncate: boolTruncate the file to zero bytes when it is opened.
permissions: Option<u32>Unix-style permission bits to use for newly-created files.
Implementations
Sourceimpl OpenFileOptions
impl OpenFileOptions
Sourcepub const fn existing() -> OpenFileOptions
pub const fn existing() -> OpenFileOptions
Open an existing file without creating or truncating it.
Sourcepub const fn create() -> OpenFileOptions
pub const fn create() -> OpenFileOptions
Open a file, creating it when it does not already exist.
Sourcepub const fn create_truncate() -> OpenFileOptions
pub const fn create_truncate() -> OpenFileOptions
Open a file, creating it when needed and truncating it to zero bytes.