RecoveryReport

Struct RecoveryReport 

pub struct RecoveryReport {
    pub intact_files: Vec<LockboxEntry>,
    pub intact_file_count: usize,
    pub partial_files: usize,
    pub corrupt_records: usize,
    pub toc_recovered: bool,
    pub variables_recovered: bool,
    pub variable_count: usize,
    pub forms_recovered: bool,
    pub form_definition_count: usize,
    pub form_record_count: usize,
}
Summary produced by lockbox recovery and salvage scans.

Fields

intact_files: Vec<LockboxEntry>

Intact file entries discovered by the scan.

intact_file_count: usize

Total number of intact files, including entries omitted from intact_files by reporting limits.

partial_files: usize

Number of file records that were only partially recoverable.

corrupt_records: usize

Number of corrupt records encountered.

toc_recovered: bool

Whether the latest TOC could be read.

variables_recovered: bool

Whether variable metadata was recovered from the latest commit root.

variable_count: usize

Number of variable values recovered.

forms_recovered: bool

Whether form metadata was recovered from the latest commit root.

form_definition_count: usize

Number of latest form definitions recovered.

form_record_count: usize

Number of form records recovered.

Implementations

Source

impl RecoveryReport

pub fn render(&self, options: &RecoveryReportOptions) -> String

Render a human-readable report.