Module vault_integration

Module vault_integration 

Narrow integration surface used by revault_vault_api.

Normal callers should use Lockbox::open. This module exists because the vault crate needs to cache an opened content key and recover from vault-stored key-directory backups.

Structs

OpenedContentKey
Decrypted content key produced by opening a key slot.
VaultOpen
Open helpers needed by the separate vault crate.