pub struct VaultOpen;Expand description
Open helpers needed by the separate vault crate.
Implementations
Sourceimpl VaultOpen
impl VaultOpen
Sourcepub fn read_lockbox_id(path: &Path) -> Result<LockboxId, Error>
pub fn read_lockbox_id(path: &Path) -> Result<LockboxId, Error>
Read the lockbox id from a lockbox file header for vault cache lookup.
Sourcepub fn export_key_directory_backup(lockbox: &Lockbox) -> Result<Vec<u8>, Error>
pub fn export_key_directory_backup(lockbox: &Lockbox) -> Result<Vec<u8>, Error>
Export key-directory backup bytes for vault-managed recovery.
Sourcepub fn path_with_password(
path: &Path,
password: &SecureString,
) -> Result<OpenedContentKey, Error>
pub fn path_with_password( path: &Path, password: &SecureString, ) -> Result<OpenedContentKey, Error>
Open the embedded key directory with a password and return the content key.
Sourcepub fn key_directory_backup_with_password(
bytes: &[u8],
password: &SecureString,
) -> Result<OpenedContentKey, Error>
pub fn key_directory_backup_with_password( bytes: &[u8], password: &SecureString, ) -> Result<OpenedContentKey, Error>
Open key-directory backup bytes with a password.
Sourcepub fn path_with_contact(
path: &Path,
contact: &ContactKeyPair,
) -> Result<OpenedContentKey, Error>
pub fn path_with_contact( path: &Path, contact: &ContactKeyPair, ) -> Result<OpenedContentKey, Error>
Open the embedded key directory with a contact keypair and return the content key.
Sourcepub fn key_directory_backup_with_contact(
bytes: &[u8],
contact: &ContactKeyPair,
) -> Result<OpenedContentKey, Error>
pub fn key_directory_backup_with_contact( bytes: &[u8], contact: &ContactKeyPair, ) -> Result<OpenedContentKey, Error>
Open key-directory backup bytes with a contact keypair.