pub struct ContactPublicKey { /* private fields */ }Expand description
Public hybrid X25519 + ML-KEM-768 contact key.
This key can be shared with a lockbox creator. It can wrap a lockbox content
key for the holder of the matching ContactKeyPair, but it cannot open a
lockbox by itself.
Implementations
Sourceimpl ContactPublicKey
impl ContactPublicKey
Sourcepub fn from_bytes(bytes: &[u8]) -> Result<ContactPublicKey, Error>
pub fn from_bytes(bytes: &[u8]) -> Result<ContactPublicKey, Error>
Decode a public contact key from its versioned Lockbox byte representation.
Returns Error::InvalidKeyMaterial if the bytes do not encode a
supported hybrid contact public key.