pub fn get_platform_vault_password() -> Result<Option<SecureString>, Error>Expand description
Loads the default local vault password from the platform secret store.
pub fn get_platform_vault_password() -> Result<Option<SecureString>, Error>Loads the default local vault password from the platform secret store.