pub struct ReadOnlyVault(/* private fields */);Expand description
Read-only view of a persistent Vault.
Implementations
Sourceimpl ReadOnlyVault
impl ReadOnlyVault
Sourcepub fn open_default(password: &SecretString) -> Result<Self>
pub fn open_default(password: &SecretString) -> Result<Self>
Opens the default store without loading private signing material.
Sourcepub fn open(root: impl AsRef<Path>, password: &SecretString) -> Result<Self>
pub fn open(root: impl AsRef<Path>, password: &SecretString) -> Result<Self>
Opens a store below root without loading private signing material.
Sourcepub fn list_private_key_names(&self) -> Result<Vec<String>>
pub fn list_private_key_names(&self) -> Result<Vec<String>>
Lists profile names without loading private keys.
Sourcepub fn list_contact_names(&self) -> Result<Vec<String>>
pub fn list_contact_names(&self) -> Result<Vec<String>>
Lists contact names without loading contact key material.
Sourcepub fn list_form_aliases(&self) -> Result<Vec<String>>
pub fn list_form_aliases(&self) -> Result<Vec<String>>
Lists form aliases stored in the encrypted metadata.
Sourcepub fn list_known_lockboxes(&self) -> Result<Vec<KnownLockbox>>
pub fn list_known_lockboxes(&self) -> Result<Vec<KnownLockbox>>
Lists remembered Lockbox paths.