LockboxEntry

Struct LockboxEntry 

pub struct LockboxEntry {
    pub path: LockboxPath,
    pub kind: LockboxEntryKind,
    pub len: u64,
    pub permissions: u32,
}
Metadata returned by lockbox listing and stat APIs.

This type contains only metadata stored in the table of contents. Symlink targets are stored in symlink page objects, so callers that need a target should call Lockbox::get_symlink_target for symlink entries.

Fields

path: LockboxPath

Canonical logical path inside the lockbox.

kind: LockboxEntryKind

Node kind.

len: u64

File length in bytes. Symlink and directory entries report zero.

permissions: u32

Stored Unix-style permission bits.