pub struct RecoveryReport {
pub intact_files: Vec<LockboxEntry>,
pub intact_file_count: usize,
pub partial_files: usize,
pub corrupt_records: usize,
pub toc_recovered: bool,
pub variables_recovered: bool,
pub variable_count: usize,
pub forms_recovered: bool,
pub form_definition_count: usize,
pub form_record_count: usize,
}Expand description
Summary produced by lockbox recovery and salvage scans.
Fields
intact_files: Vec<LockboxEntry>Intact file entries discovered by the scan.
intact_file_count: usizeTotal number of intact files, including entries omitted from
intact_files by reporting limits.
partial_files: usizeNumber of file records that were only partially recoverable.
corrupt_records: usizeNumber of corrupt records encountered.
toc_recovered: boolWhether the latest TOC could be read.
variables_recovered: boolWhether variable metadata was recovered from the latest commit root.
variable_count: usizeNumber of variable values recovered.
forms_recovered: boolWhether form metadata was recovered from the latest commit root.
form_definition_count: usizeNumber of latest form definitions recovered.
form_record_count: usizeNumber of form records recovered.
Implementations
Sourceimpl RecoveryReport
impl RecoveryReport
Sourcepub fn render(&self, options: &RecoveryReportOptions) -> String
pub fn render(&self, options: &RecoveryReportOptions) -> String
Render a human-readable report.