Narrow integration surface used by revault_vault_api.
Normal callers should use Lockbox::open. This module exists because
the vault crate needs to cache an opened content key and recover from
vault-stored key-directory backups.
Structs
- Opened
Content Key - Decrypted content key produced by opening a key slot.
- Vault
Open - Open helpers needed by the separate vault crate.