start

Function start 

pub fn start() -> Result<(), Error>
Starts the session agent if it is not already running.

Callers must only invoke this after checking the user’s auto-open policy. Secret-cache writes deliberately do not start the agent themselves because they may occur while a vault file lock is held.